@@ -4,6 +4,7 @@ use strict;
 use warnings;
 
 use Beekeeper::Worker ':log';
+use Beekeeper::Logger ':log_levels';
 use base 'Beekeeper::Worker';
 
 use Exporter 'import';
@@ -11,6 +12,7 @@ use Exporter 'import';
 our @EXPORT = (
     @Beekeeper::Worker::EXPORT,
     @Beekeeper::Worker::EXPORT_OK,
+    @Beekeeper::Logger::EXPORT_OK,
 );
 
 
