@@ -8,14 +8,14 @@ fi
 
 case "${1-start}" in
     'start')
-        bkpr --pool "broker"  start
+        bkpr --pool "myapp-broker" start
         bkpr --pool "myapp-A" start
         bkpr --pool "myapp-B" start
         ;;
     'stop')
         bkpr --pool "myapp-A" stop
         bkpr --pool "myapp-B" stop
-        bkpr --pool "broker"  stop
+        bkpr --pool "myapp-broker" stop
         ;;
     'restart')
         bkpr --pool "myapp-A" restart
