@@ -6,10 +6,14 @@ use warnings;
 BEGIN { unshift @INC, ($ENV{'PERL5LIB'} =~ m/([^:]+)/g); }
 
 
-use Beekeeper::Client;
-use Time::HiRes qw( time sleep );
+use MyApp::Service::Flood;
+use Time::HiRes 'time';
+use Term::ReadKey;
 use Getopt::Long;
 
+ReadMode "cbreak";
+END { ReadMode "restore" }
+
 my ($opt_count, $opt_number, $opt_rate, $opt_type, $opt_size, $opt_bench, $opt_help);
 my $no_args = (@ARGV == 0) ? 1 : 0;
 
@@ -30,20 +34,20 @@ Flood with requests a test worker pool.
   -t, --type str   type of requests to be made (N, S, A or F)
   -c, --count N    how many requests to be made
   -r, --rate  N    sustain a rate of N requests per second
-  -s, --size  N    size in KB of requests, default is 0
+  -s, --size  N    size in KiB of requests, default is 0
   -n, --n     N    alias for --count
   -b, --benchmark  run a set of predefined benchmarks
   -h, --help       display this help and exit
 
-To create a burst of 5000 notifications:
+Create a burst of 5000 notifications:
 
   flood --type N --count 5000
 
-To create a constant load of 100 requests per second:
+Create a constant load of 100 requests per second:
 
   flood --type S --rate 100
 
-Run a predefined set of benchmarks
+Run a predefined set of benchmarks:
 
   flood --benchmark
 
@@ -86,98 +90,108 @@ sub time_this {
     my $payload = { data => 'X' x ($size * 1024) };
 
     my $type = $args{'type'} || 'N';
-    my @async_calls;
     my $code;
 
     if ($type =~ m/^N(otification)?/i) {
         $type = 'notifications';
         $code = sub {
-            $client->send_notification(
-                method => 'myapp.test.flood', 
-                params => $payload,
-            );
+            # Measure send time
+            MyApp::Service::Flood->notify( $payload );
         };
     }
     elsif ($type =~ m/^S(ync)?/i) {
         $type = 'sync calls';
         $code = sub {
-            $client->call_remote(
-                method => 'myapp.test.echo', 
-                params => $payload,
-            );
+            # Measure response time
+            MyApp::Service::Flood->echo( $payload );
         };
     }
     elsif ($type =~ m/^A(sync)?/i) {
         $type = 'async calls';
         $code = sub {
-            push @async_calls, $client->call_remote_async(
-                method => 'myapp.test.echo', 
-                params => $payload,
-            );
+            # Measure response time
+            MyApp::Service::Flood->async_echo( $payload, sub {} );
         };
     }
     elsif ($type =~ m/^F(ire)?/i) {
         $type = 'fire & forget';
         $code = sub {
-            $client->fire_remote(
-                method => 'myapp.test.echo', 
-                params => $payload,
-            );
+            # Measure send time only
+            MyApp::Service::Flood->fire_echo( $payload );
         };
     }
     else {
         die "type must be one of (N)otification, (S)ync, (A)sync or (F)ire and forget\n";
     }
 
-    my $rate = $args{'rate'} ? (1 / $args{'rate'}) : 0;
-    my $max_count = $args{'count'} || ($rate ? -1 : 1000);
-
-    my $quit;
-
-    if ($rate) {
-        print "Press ctrl-C to stop\n";
-        $SIG{'INT'} = sub { $quit = 1; print "\b\b"; };
-    }
+    my $count = $args{'count'};
+    my $rate  = $args{'rate'};
+    my $batch = $rate || $count || 1000;
+    my $total = 0;
 
     local $| = 1;
-    printf( "%s %-15s of %3s Kb  ", $max_count, $type, $size ) if (!$rate);
 
-    my $count = 0;
-    my $start = time();
-    my $next = $start;
-    my $sleept = 0;
-    my $sleep;
+    BENCH: {
 
-    while (1) {
+        printf( "%s %-15s of %3s Kb  ", $batch, $type, $size );
 
-        &$code();
+        my $start = time();
 
-        $count++;
+        for (1..$batch) {
+            &$code();
+        }
 
-        last if ($quit || $count == $max_count);
+        $total += $batch;
+
+        if ($type eq 'async calls') {
+
+            # Run the event loop in order to receive responses
+            my $cv = AnyEvent->condvar;
+            AnyEvent::postpone { $cv->send };
+            $cv->recv;
+        }
+
+        my $took = time() - $start;
+        my $clk = sprintf("%.3f", $took);
+        my $cps = sprintf("%.0f", $batch / $took);
+        my $avg = sprintf("%.2f", $took / $batch * 1000);
 
         if ($rate) {
-            $next += $rate;
-            $sleep = $next - time();
-            if ($sleep > 0) {
-                $sleept += $sleep;
-                sleep($sleep);
+
+            printf( "in %6s sec  %6s /sec %6s ms each", $clk, $cps, $avg );
+
+            if ($took <= 1) {
+
+                my $sleep = 1 - $took;
+                my $cv = AnyEvent->condvar;
+                AnyEvent->now_update;
+                my $tmr = AnyEvent->timer( after => $sleep, cb => $cv);
+                $cv->recv;
             }
+            else {
+                my $ovl = int(abs(($took - 1) * 100)); 
+                print "   $ovl\% overload";
+            }
+
+            print "\n";
+
+            last if $count && $total >= $count;
+
+            my $key = ReadKey(-1);
+            last if $key;
+
+            redo BENCH;
+        }
+        else {
+
+            printf( "in %6s sec  %6s /sec %6s ms each\n", $clk, $cps, $avg );
         }
     }
 
-    if ($type eq 'async call') {
+    if ($type eq 'async calls' && !$rate) {
+        # Ensure that all responses are received before running the next benchmark
         $client->wait_async_calls;
-        @async_calls = ();
     }
-
-    my $ellapsed = time() - $start - $sleept;
-    my $took = sprintf("%.3f", $ellapsed);
-    my $tps = sprintf("%.0f", $count / $ellapsed);
-    my $avg = sprintf("%.2f", $ellapsed / $count * 1000);
-
-    printf( "%s %-15s of %3s Kb  ", $count, $type, $size ) if ($rate);
-    printf( "in %6s sec  %6s /sec %6s ms each\n", $took, $tps, $avg );
 }
 
 sub run_benchmarks {
