@@ -6,7 +6,7 @@ use warnings;
 use Beekeeper::Worker ':log';
 use base 'Beekeeper::Worker';
 
-use Beekeeper::Worker::Util 'shared_cache';
+use Beekeeper::Worker::Extension::SharedCache;
 use Time::HiRes 'sleep';
 
 =pod
@@ -20,9 +20,9 @@ Simple worker used to test shared cache.
 sub on_startup {
     my $self = shift;
 
-    $self->{Cache} = $self->shared_cache( id => "test", max_age => 10 );
+    $self->{Cache} = $self->shared_cache( id => "test", max_age => 20 );
 
-    $self->accept_jobs(
+    $self->accept_remote_calls(
         'cache.set'  => 'set',
         'cache.get'  => 'get',
         'cache.del'  => 'del',
@@ -36,7 +36,7 @@ sub on_startup {
 sub authorize_request {
     my ($self, $req) = @_;
 
-    return REQUEST_AUTHORIZED;
+    return BKPR_REQUEST_AUTHORIZED;
 }
 
 sub get {
